//$Id: resource-util.h,v 1.3 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_RESOURCE_UTIL_H
#define GUIKACHU_RESOURCE_UTIL_H

#include <glib.h>
#include "resource.h"

namespace Guikachu
{
    namespace Resources
    {
	const std::string type_id_from_type (Resources::Type type) G_GNUC_CONST;
    }
}

#endif /* !GUIKACHU_RESOURCE_UTIL_H */
